aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/vendor/github.com/google/pprof/driver
diff options
context:
space:
mode:
authorHana (Hyang-Ah) Kim <hyangah@gmail.com>2018-11-06 17:48:08 -0500
committerHyang-Ah Hana Kim <hyangah@gmail.com>2018-11-07 12:27:21 +0000
commitc0a40e4fe5d4649672d0d430ca26551841fc4852 (patch)
tree4ccd82b68f0795d68bc43caff3cba7c9fabdb4d8 /src/cmd/vendor/github.com/google/pprof/driver
parent1100df58238a1b1c55af148a880b48caf4be6504 (diff)
downloadgo-c0a40e4fe5d4649672d0d430ca26551841fc4852.tar.xz
cmd/vendor: update github.com/google/pprof
Sync @ fde099a (Oct 26, 2018) Also update misc/nacl/testzip.proto to include new testdata. Change-Id: If41590be9f395a591056e89a417b589c4ba71b1a Reviewed-on: https://go-review.googlesource.com/c/147979 Run-TryBot: Hyang-Ah Hana Kim <hyangah@gmail.com> TryBot-Result: Gobot Gobot <gobot@golang.org> Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
Diffstat (limited to 'src/cmd/vendor/github.com/google/pprof/driver')
-rw-r--r--src/cmd/vendor/github.com/google/pprof/driver/driver.go43
1 files changed, 25 insertions, 18 deletions
diff --git a/src/cmd/vendor/github.com/google/pprof/driver/driver.go b/src/cmd/vendor/github.com/google/pprof/driver/driver.go
index 3735d6ace9..b1c745bacd 100644
--- a/src/cmd/vendor/github.com/google/pprof/driver/driver.go
+++ b/src/cmd/vendor/github.com/google/pprof/driver/driver.go
@@ -17,6 +17,7 @@ package driver
import (
"io"
+ "net/http"
"regexp"
"time"
@@ -48,13 +49,14 @@ func (o *Options) internalOptions() *plugin.Options {
}
}
return &plugin.Options{
- Writer: o.Writer,
- Flagset: o.Flagset,
- Fetch: o.Fetch,
- Sym: sym,
- Obj: obj,
- UI: o.UI,
- HTTPServer: httpServer,
+ Writer: o.Writer,
+ Flagset: o.Flagset,
+ Fetch: o.Fetch,
+ Sym: sym,
+ Obj: obj,
+ UI: o.UI,
+ HTTPServer: httpServer,
+ HTTPTransport: o.HTTPTransport,
}
}
@@ -64,13 +66,14 @@ type HTTPServerArgs plugin.HTTPServerArgs
// Options groups all the optional plugins into pprof.
type Options struct {
- Writer Writer
- Flagset FlagSet
- Fetch Fetcher
- Sym Symbolizer
- Obj ObjTool
- UI UI
- HTTPServer func(*HTTPServerArgs) error
+ Writer Writer
+ Flagset FlagSet
+ Fetch Fetcher
+ Sym Symbolizer
+ Obj ObjTool
+ UI UI
+ HTTPServer func(*HTTPServerArgs) error
+ HTTPTransport http.RoundTripper
}
// Writer provides a mechanism to write data under a certain name,
@@ -100,12 +103,16 @@ type FlagSet interface {
// single flag
StringList(name string, def string, usage string) *[]*string
// ExtraUsage returns any additional text that should be
// printed after the standard usage message.
// The typical use of ExtraUsage is to show any custom flags
// defined by the specific pprof plugins being used.
ExtraUsage() string
+ // AddExtraUsage appends additional text to the end of the extra usage message.
+ AddExtraUsage(eu string)
+
// Parse initializes the flags with their values for this run
// and returns the non-flag command line arguments.
// If an unknown flag is encountered or there are no arguments,
@@ -100,12 +103,16 @@ type FlagSet interface {
// single flag
StringList(name string, def string, usage string) *[]*string
- // ExtraUsage returns any additional text that should be
- // printed after the standard usage message.
- // The typical use of ExtraUsage is to show any custom flags
- // defined by the specific pprof plugins being used.
+ // ExtraUsage returns any additional text that should be printed after the
+ // standard usage message. The extra usage message returned includes all text
+ // added with AddExtraUsage().
+ // The typical use of ExtraUsage is to show any custom flags defined by the
+ // specific pprof plugins being used.
ExtraUsage() string